package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TRegionMapper;
import com.ruoyi.system.domain.TRegion;
import com.ruoyi.system.service.ITRegionService;

/**
 * 行政区域Service业务层处理
 * 
 * @author zhengjie
 * @date 2023-08-15
 */
@Service
public class TRegionServiceImpl implements ITRegionService 
{
    @Autowired
    private TRegionMapper tRegionMapper;

    /**
     * 查询行政区域
     * 
     * @param id 行政区域主键
     * @return 行政区域
     */
    @Override
    public TRegion selectTRegionById(Integer id)
    {
        return tRegionMapper.selectTRegionById(id);
    }

    /**
     * 查询行政区域列表
     * 
     * @param tRegion 行政区域
     * @return 行政区域
     */
    @Override
    public List<TRegion> selectTRegionList(TRegion tRegion)
    {
        return tRegionMapper.selectTRegionList(tRegion);
    }

    /**
     * 新增行政区域
     * 
     * @param tRegion 行政区域
     * @return 结果
     */
    @Override
    public int insertTRegion(TRegion tRegion)
    {
        if (tRegion.getParentId() == 0){
            TRegion t = tRegionMapper.selectTRegionById(1);
            tRegion.setCreateTime(DateUtils.getNowDate());
            tRegion.setParentId(1);
            tRegion.setAncestors("0,1");
            return tRegionMapper.insertTRegion(tRegion);
        }else{
            TRegion t = tRegionMapper.selectTRegionById(tRegion.getParentId());
            tRegion.setCreateTime(DateUtils.getNowDate());
            tRegion.setAncestors(t.getAncestors() + "," + tRegion.getParentId());
            return tRegionMapper.insertTRegion(tRegion);
        }
    }

    /**
     * 修改行政区域
     * 
     * @param tRegion 行政区域
     * @return 结果
     */
    @Override
    public int updateTRegion(TRegion tRegion)
    {
        tRegion.setUpdateTime(DateUtils.getNowDate());
        return tRegionMapper.updateTRegion(tRegion);
    }

    /**
     * 批量删除行政区域
     * 
     * @param ids 需要删除的行政区域主键
     * @return 结果
     */
    @Override
    public int deleteTRegionByIds(Integer[] ids)
    {
        return tRegionMapper.deleteTRegionByIds(ids);
    }

    /**
     * 删除行政区域信息
     * 
     * @param id 行政区域主键
     * @return 结果
     */
    @Override
    public int deleteTRegionById(Integer id)
    {
        return tRegionMapper.deleteTRegionById(id);
    }
}
